# frozen_string_literal: true
module NexClient
  class App < BaseResource
    property :created_at, type: :time
    property :updated_at, type: :time
    property :ssl_enabled, type: :boolean
    property :persistent_storage, type: :boolean

    # PATCH <api_root>/apps/:id/restart
    custom_endpoint :restart, on: :member, request_method: :patch

    # PATCH <api_root>/apps/:id/scale_up
    custom_endpoint :scale_up, on: :member, request_method: :patch

    # PATCH <api_root>/apps/:id/scale_down
    custom_endpoint :scale_down, on: :member, request_method: :patch

    # PATCH <api_root>/apps/:id/link_scm
    custom_endpoint :link_scm, on: :member, request_method: :patch

    # PATCH <api_root>/apps/:id/unlink_scm
    custom_endpoint :unlink_scm, on: :member, request_method: :patch

    # GET <api_root>/apps/:id/logs
    custom_endpoint :logs, on: :member, request_method: :get

    def preferred_url
      domain = self.domains.first rescue NexClient::Domain.find('origin.name' => self.name).first
      if domain
        "#{domain.ssl_available ? 'https':'http'}://#{domain.cname}"
      else
        "#{self.ssl_enabled ? 'https' : 'http'}://#{self.url}"
      end
    end
  end
end
