# frozen_string_literal: true
module NexClient
  module Commands
    module CubeTemplates
      extend Helpers

      TEMPLATES_TITLE = "Cube Templates".colorize(:red)
      TEMPLATES_HEADERS = ['id','name','image','tag','layer','min_pu','stack'].map(&:upcase)

      def self.list(args,opts)
        filters = {}
        filters[:human_id] = opts.name if opts.name.present?
        filters[:stack] = opts.stack if opts.stack.present?
        filters[:image] = opts.image if opts.image.present?

        # Create table
        list = NexClient::CubeTemplate.where(filters).order('human_id')
        self.display_templates(list)

        # Loop through results
        while (list.pages.links||{})['next']
          return true if ask("Press enter for next page ('q' to quit)") =~ /q/
          list = list.pages.next
          self.display_templates(list)
        end
      end

      def self.display_templates(list)
        table = Terminal::Table.new title: TEMPLATES_TITLE, headings: TEMPLATES_HEADERS do |t|
          [list].flatten.compact.each do |e|
            t.add_row(self.format_record(e))
          end
        end
        puts table
        puts "\n"
      end

      def self.format_record(record)
        [
          record.id,
          record.human_id,
          record.image,
          record.tag,
          record.layer,
          record.min_pu,
          record.stack
        ]
      end
    end
  end
end
