# frozen_string_literal: true
module NexClient
  module Commands
    module Organizations
      extend Helpers

      ORGS_TITLE = "Organizations".colorize(:green)
      ORGS_HEADERS = ['id','name','handle'].map(&:upcase)

      def self.list(args,opts)
        # Display list
        list = NexClient::Organization.order('handle')
        self.display_organizations(list)

        # Loop through results
        while (list.pages.links||{})['next']
          return true if ask("Press enter for next page ('q' to quit)") =~ /q/
          list = list.pages.next
          self.display_organizations(list)
        end
      end

      def self.display_organizations(list)
        table = Terminal::Table.new title: ORGS_TITLE, headings: ORGS_HEADERS do |t|
          [list].flatten.compact.each do |e|
            t.add_row([e.id,e.name,e.handle])
          end
        end
        puts table
        puts "\n"
      end

    end
  end
end
